@@ -29,9 +29,9 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
 
-__version__ = "0.3"
+__version__ = "0.4"
 
-from xsge import gui, transition
+from xsge import gui, physics
 
 
-__all__ = ["gui", "transition"]
+__all__ = ["gui", "physics"]
